@@ -63,14 +63,10 @@ class CustomIntegration:
     def create_order(self):
         return self.order.create_order()
 
-    def update_order(self):
-        return self.order.update_order()
-
-    def status_order(self, reference_id=''):
-        if not reference_id or len(reference_id) == 0:
+    def status_order(self, order_reference=''):
+        if not order_reference or len(order_reference) == 0:
             return "reference_id is required field"
-
-        return self.order.status_order(reference_id)
+        return self.order.status_order(order_reference=order_reference)
 
     def get_checkout_button(self):
         return self.buttons.get_checkout_button_image_url()
@@ -83,12 +79,11 @@ custom_integration = CustomIntegration()
 authenticate = custom_integration.authenticate_builder
 set_order = custom_integration.set_order
 create_order = custom_integration.create_order
-update_order = custom_integration.update_order
+order_status = custom_integration.status_order
+
 customer_authenticator = custom_integration.single_sign_on
 single_sign_on_set_values = custom_integration.single_sign_on_set_values
-status_order = custom_integration.status_order
 get_customer_profile = custom_integration.get_sso_customer_profile
-update_shipping = custom_integration.foo()
 
 checkout_button_image = custom_integration.get_checkout_button
 sso_login_button_image = custom_integration.get_sso_login_button
