@@ -1,8 +1,8 @@
 # __author__ = Sadaqatullah Noonari
 
 class Base:
-    __base_url = 'https://api-dev.bsecure.app'
-    __base_login_app_url = 'https://login-dev.bsecure.app'
+    __base_url = 'https://api.bsecure.pk'
+    __base_login_app_url = 'https://login.bsecure.pk'
     __key_grant_type = 'grant_type'
     __value_grant_type = 'client_credentials'
 
