@@ -1,3 +1,5 @@
+# __author__ = Sadaqatullah Noonari
+
 from json import loads, dumps
 from requests import post, get
 from bSecure.helpers.constants import constants
@@ -26,22 +28,11 @@ class Order:
         content = loads(response.content)
         return content
 
-    def update_order(self):
-        url = constants.get_update_order_url()
-        print(getattr(self, constants.get_key_header()))
-        response = post(
-            url,
-            data=getattr(self, constants.get_key_order_details()),
-            headers=getattr(self, constants.get_key_header())
-        )
-        content = loads(response.content)
-        return content
-
-    def status_order(self, reference_id):
+    def status_order(self, order_reference):
         url = constants.get_status_order_url()
         response = get(
             url,
-            data={'code': reference_id},
+            data={'code': order_reference},
             headers=getattr(self, constants.get_key_header())
         )
-        return loads(response.content)
+        return loads(response.content).get('body')
